Module condition

Module condition 

Step condition evaluation (used by if_do and while_do).

Structs

FieldComparison
A comparison of a workflow data field against an expected value.

Enums

ComparisonOp
Comparison operators for field conditions.
StepCondition
A condition that determines whether a workflow step should execute.